=========================================
django-organizations: multi-user accounts
=========================================

django-organizations is an application that provides group account
functionality for Django, allowing user access and rights to be consolidated
into group accounts.

Contents:

.. toctree::
    :maxdepth: 2

    getting_started
    usage
    custom_usage
    cookbook
    signals
    reference/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Sponsors
========

`Muster <https://www.muster.com/home?utm_source=readthedocs&campaign=opensource>`_ is building precision advocacy software to impact policy through grassroots action.

.. image:: https://www.muster.com/hs-fs/hubfs/muster_logo-2.png?width=600&name=muster_logo-2.png
  :target: https://www.muster.com/home?utm_source=readthedocs&campaign=opensource
  :width: 400
  :alt: Alternative text

